README
======

This package contains solvers for direct displacement-based design

Setting up tests
----------------

If using PyCharm:
 1. make sure the navigation bar is showing (View>Navigation bar)
 2. Edit Configuration (top right)
 3. Click the plus symbol in the pop up window
 4. Select pytest from the drop down menu
 5. point it to the tests folder
 6. Call the configuration "All tests"


What is this repository for?
----------------------------

* Quick summary
* Version

How do I get set up?
--------------------

* Summary of set up
* Configuration
* Dependencies
* Database configuration
* How to run tests
* Deployment instructions

Contribution guidelines
-----------------------

.. Standard

* Writing tests
* Code review
* Other guidelines
